==> paraview-5.8.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/paraview-5.8/vtk/vtkmodules-vtk-python-module-properties.cmake <==
set_property(TARGET "VTK::CommonCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::WebCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonMath" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonTransforms" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonDataModel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonExecutionModel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOImage" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOXMLParser" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOXML" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonMisc" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingContext2D" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingFreeType" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOExport" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::WebGLExporter" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersGeneral" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersSources" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::InteractionWidgets" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ViewsCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ViewsContext2D" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::TestingRendering" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingSceneGraph" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingVolume" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingRayTracing" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingMath" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingVolumeOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingVolumeAMR" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingParallel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingMatplotlib" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingLabel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingLICOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingContextOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ParallelMPI4Py" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOLegacy" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOXdmf2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOVeraOut" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOVPIC" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOTecplotTable" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOTRUCHAS" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOSegY" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOXdmf3" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOParallelXML" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IONetCDF" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOParallelNetCDF" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOLSDyna" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOParallelLSDyna" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOExodus" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOParallelExodus" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOPLY" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOPIO" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOPDAL" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOMovie" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOOggTheora" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOMotionFX" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOGeometry" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOParallel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOMPIImage" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOInfovis" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonColor" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingSources" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::InfovisCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOImport" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOH5part" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOVideo" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOFFMPEG" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingGL2PSOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOExportGL2PS" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOEnSight" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOCityGML" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOAsynchronous" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOAMR" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOGDAL" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingColor" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingAnnotation" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::InteractionStyle" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingHybrid" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersPython" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersProgrammable" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersModeling" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersPoints" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersVerdict" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ParallelCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelVerdict" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersStatistics" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelStatistics" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonSystem" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersGeometry" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersExtraction" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersTexture" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ParallelMPI" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelGeometry" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonComputationalGeometry" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersFlowPaths" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelFlowPaths" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelDIY2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingGeneral" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersHyperTree" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersHybrid" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersGeneric" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersAMR" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelMPI" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::DomainsChemistry" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::DomainsChemistryOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ChartsCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingFourier" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::AcceleratorsVTKm" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")

==> paraview-5.9.0-2-x86_64.pkg.tar.zst: usr/lib/cmake/paraview-5.9/vtk/vtkmodules-vtk-python-module-properties.cmake <==
set_property(TARGET "VTK::CommonCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::WebCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonMath" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonTransforms" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonDataModel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonExecutionModel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOImage" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOXMLParser" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOXML" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonMisc" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingContext2D" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingFreeType" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingSceneGraph" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingVtkJS" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOExport" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::WebGLExporter" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersGeneral" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersSources" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::InteractionWidgets" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ViewsCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ViewsContext2D" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::TestingRendering" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOLegacy" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::DomainsChemistry" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingUI" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingVolume" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingRayTracing" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingMath" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingVolumeOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingVolumeAMR" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingParallel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingMatplotlib" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingLabel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingLICOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingContextOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ParallelMPI4Py" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOXdmf2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOVeraOut" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOVPIC" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOTecplotTable" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOTRUCHAS" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOSegY" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOXdmf3" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOParallelXML" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IONetCDF" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOParallelNetCDF" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOLSDyna" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOParallelLSDyna" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOExodus" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOParallelExodus" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOPLY" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOPIO" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOPDAL" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOMovie" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOOggTheora" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOMotionFX" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOGeometry" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOParallel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOMPIImage" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ParallelCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOIoss" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOInfovis" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonColor" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingSources" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::InfovisCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOImport" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOH5part" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOVideo" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOFFMPEG" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingGL2PSOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOExportGL2PS" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOEnSight" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOCityGML" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOCONVERGECFD" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOAsynchronous" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOAMR" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::IOGDAL" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingColor" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::RenderingAnnotation" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::InteractionStyle" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingHybrid" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersPython" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersProgrammable" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersModeling" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersPoints" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersVerdict" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelVerdict" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersStatistics" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelStatistics" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonSystem" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersGeometry" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersExtraction" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersHybrid" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersTexture" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ParallelMPI" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelGeometry" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::CommonComputationalGeometry" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersFlowPaths" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelFlowPaths" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelDIY2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingGeneral" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersHyperTree" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersGeneric" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersAMR" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::FiltersParallelMPI" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::DomainsChemistryOpenGL2" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ChartsCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::ImagingFourier" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::AcceleratorsVTKmCore" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::AcceleratorsVTKmDataModel" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
set_property(TARGET "VTK::AcceleratorsVTKmFilters" PROPERTY "INTERFACE_vtk_module_python_package" "vtkmodules")
